@@ -1,16 +1,17 @@
 /*
- * RasterReader.h
+ * RasterReader.hpp
  *
  *  Created on: 20.07.2015
  *      Author: Henning
  */
 
+// networkit-format
+
 #ifndef NETWORKIT_IO_RASTER_READER_HPP_
 #define NETWORKIT_IO_RASTER_READER_HPP_
 
-#include <utility>
-#include <vector>
 #include <string>
+#include <vector>
 
 namespace NetworKit {
 
@@ -19,8 +20,7 @@ namespace NetworKit {
  * Coordinate transformation into the unit square takes place.
  * Within each grid cell, points get a random location.
  */
-class RasterReader {
-private:
+class RasterReader final {
     double normalizationFactor;
 
 public:
@@ -28,13 +28,14 @@ public:
      * @param[in] Factor by which population per grid cell should be multiplied
      */
     RasterReader(double normalizationFactor);
-    virtual ~RasterReader() = default;
+
+    ~RasterReader() = default;
 
     /**
      * @param[in] path Path and name of file to be read.
      * @return Vectors of x- and y-coordinates of the points.
      */
-    std::pair<std::vector<double>, std::vector<double> > read(const std::string& path);
+    std::pair<std::vector<double>, std::vector<double>> read(const std::string &path);
 };
 
 } /* namespace NetworKit */
