@@ -1,4 +1,4 @@
-/* GCE.h
+/* GCE.hpp
  *
  * Created on: 06.05.2013
  * Author: cls
@@ -10,13 +10,11 @@
 
 #include <unordered_set>
 
-#include <networkit/scd/SelectiveCommunityDetector.hpp>
 #include <networkit/auxiliary/SetIntersector.hpp>
-
+#include <networkit/scd/SelectiveCommunityDetector.hpp>
 
 namespace NetworKit {
 
-
 /**
  * The Greedy Community Expansion algorithm.
  *
@@ -28,21 +26,18 @@ public:
 
     GCE(const Graph& G, std::string objective);
 
-
-    std::map<node, std::set<node> >  run(const std::set<node>& seeds) override;
+    std::map<node, std::set<node>> run(const std::set<node>& seeds) override;
 
     /**
-     * @param[in]	s	seed node
+     * @param[in]  s  seed node
      *
-     * @param[out]		community as a set of nodes
+     * @param[out]    community as a set of nodes
      */
     std::set<node> expandSeed(node s);
 
-protected:
-
+private:
     std::string objective;    // name of objective function
 
-
 };
 
 } /* namespace NetworKit */
