@@ -5,6 +5,8 @@
  *      Author: cls
  */
 
+// networkit-format
+
 #include <algorithm>
 #include <atomic>
 #include <memory>
@@ -16,26 +18,23 @@ namespace NetworKit {
 
 Partition::Partition() : z(0), omega(0), data(0) {}
 
-Partition::Partition(const std::vector<index>& data) : z(data.size()), omega(), data(data) {
+Partition::Partition(const std::vector<index> &data) : z(data.size()), omega(), data(data) {
     auto max_elem = *std::max_element(data.begin(), data.end());
     this->omega = (max_elem == none) ? 0 : max_elem;
 }
 
-
 Partition::Partition(index z) : z(z), omega(0), data(z, none) {}
 
 Partition::Partition(index z, index defaultValue) : z(z), omega(0), data(z, defaultValue) {}
 
 void Partition::allToSingletons() {
     setUpperBound(numberOfElements());
-    parallelForEntries([&](index e, index) {
-        data[e] = e;
-    });
+    parallelForEntries([&](index e, index) { data[e] = e; });
 }
 
 index Partition::mergeSubsets(index s, index t) {
-    assert (s <= omega);
-    assert (t <= omega);
+    assert(s <= omega);
+    assert(t <= omega);
     if (s != t) {
         index m = newSubsetId(); // new id for merged set
         for (index e = 0; e < this->z; ++e) {
@@ -50,14 +49,15 @@ index Partition::mergeSubsets(index s, index t) {
 
 count Partition::numberOfSubsets() const {
     auto n = upperBound();
-    std::unique_ptr<std::atomic<bool>[]> exists(new std::atomic<bool>[n]{}); // a boolean vector would not be thread-safe
+    // a boolean vector would not be thread-safe
+    std::unique_ptr<std::atomic<bool>[]> exists(new std::atomic<bool>[n] {});
     this->parallelForEntries([&](index, index s) {
         if (s != none) {
             exists[s] = true;
         }
     });
     count k = 0; // number of actually existing clusters
-    #pragma omp parallel for reduction(+:k)
+#pragma omp parallel for reduction(+ : k)
     for (omp_index i = 0; i < static_cast<omp_index>(n); ++i) {
         if (exists[i]) {
             k++;
@@ -75,19 +75,20 @@ void Partition::compact(bool useTurbo) {
         usedIds.erase(last, usedIds.end());
         i = usedIds.size();
 
-        this->parallelForEntries([&](index e, index s){ // replace old SubsetIDs with the new IDs
+        this->parallelForEntries([&](index e, index s) { // replace old SubsetIDs with the new IDs
             if (s != none) {
-                data[e] = std::distance(usedIds.begin(), std::lower_bound(usedIds.begin(), usedIds.end(), s));
+                data[e] = std::distance(usedIds.begin(),
+                                        std::lower_bound(usedIds.begin(), usedIds.end(), s));
             }
         });
     } else {
         std::vector<index> compactingMap(this->upperBound(), none);
-        this->forEntries([&](index, index s){
+        this->forEntries([&](index, index s) {
             if (s != none && compactingMap[s] == none) {
                 compactingMap[s] = i++;
             }
         });
-        this->parallelForEntries([&](index e, index s){ // replace old SubsetIDs with the new IDs
+        this->parallelForEntries([&](index e, index s) { // replace old SubsetIDs with the new IDs
             if (s != none) {
                 data[e] = compactingMap[s];
             }
@@ -109,7 +110,7 @@ std::vector<count> Partition::subsetSizes() const {
 std::map<index, count> Partition::subsetSizeMap() const {
     std::map<index, count> subset2size;
 
-    this->forEntries([&](index, index s){
+    this->forEntries([&](index, index s) {
         if (s != none) {
             subset2size[s] += 1;
         }
@@ -119,7 +120,7 @@ std::map<index, count> Partition::subsetSizeMap() const {
 }
 
 std::set<index> Partition::getMembers(index s) const {
-    assert (s <= omega);
+    assert(s <= omega);
     std::set<index> subset;
     for (index e = 0; e < this->z; ++e) {
         if (data[e] == s) {
@@ -130,18 +131,17 @@ std::set<index> Partition::getMembers(index s) const {
 }
 
 std::vector<index> Partition::getVector() const {
-    return this->data; //FIXME is this appropriate? - why not?
+    return data;
 }
 
-
-std::set<std::set<index> > Partition::getSubsets() const {
-    std::vector<std::set<index> > table(omega+1);
-    this->forEntries([&](index e, index s){
+std::set<std::set<index>> Partition::getSubsets() const {
+    std::vector<std::set<index>> table(omega + 1);
+    this->forEntries([&](index e, index s) {
         assert(s <= omega);
         table[s].insert(e);
     });
 
-    std::set<std::set<index> > subsets;
+    std::set<std::set<index>> subsets;
     for (const auto &set : table) {
         if (!set.empty()) {
             subsets.insert(set);
@@ -152,9 +152,7 @@ std::set<std::set<index> > Partition::getSubsets() const {
 
 void Partition::allToOnePartition() {
     omega = 0;
-    this->parallelForEntries([&](index e, index) {
-        this->data[e] = 0;
-    });
+    this->parallelForEntries([&](index e, index) { this->data[e] = 0; });
 }
 
 std::set<index> Partition::getSubsetIds() const {
