@@ -236,12 +236,15 @@ class Profile:
 	def create(cls, G, preset="default", config=None):
 		""" creates a profile object
 
-		Args:
+		Parameters:
+		-----------
 			G: networkit.Graph
 				Graph to profile
 			preset: name of preset configuration: "complete", "minimal", "default"
 			config: object to control some aspects of the generation behaviour (Config)
+		
 		Returns:
+		--------
 			profile object
 		"""
 
@@ -284,7 +287,7 @@ class Profile:
 			("Centrality.Katz",						"Node Centrality",	"Katz Centrality",
 				True,	funcScores,	"Score",				centrality.KatzCentrality,				(G, )),
 			("Centrality.Betweenness", 				"Node Centrality",	"Betweenness",
-				True,	funcScores,	"Score",				centrality.ApproxBetweenness2,			(G, 10, True)),
+				True,	funcScores,	"Score",				centrality.EstimateBetweenness,			(G, 10, True)),
 			("Centrality.Closeness",				"Node Centrality",	"Closeness",
 				True,	funcScores,	"Score",				centrality.ApproxCloseness,				(G, min(10, G.numberOfNodes()), True)),
 			("Partition.Communities", 				"Partition",		"Communities",
@@ -311,7 +314,8 @@ class Profile:
 	def setVerbose(cls, verbose=False, level=0, filename=""):
 		""" set verbose behaviour of all public methods
 
-		Args:
+		Parameters:
+		-----------
 			verbose: enable/disable display verbose
 			level: set level of verbose (0, 1)
 			filename: enable/disable additional logfile support to given file
@@ -356,10 +360,11 @@ class Profile:
 		return self.__measures[measure]["time"]
 
 
-	def output(self, outputType, directory, style="light", color=colors["green"], parallel=False):
+	def output(self, outputType, directory, filename='graph', style="light", color=colors["green"], parallel=False):
 		""" outputs a computed profile to disk
 
-		Args:
+		Parameters:
+		-----------
 			outputType: profile output format ("HTML", "LaTeX")
 			directory: directory to write
 			style: style of generated output ("light")
@@ -375,8 +380,6 @@ class Profile:
 			if o == outputType:
 				break
 
-		filename  = "{0}.".format(self.__G.getName())
-
 		result = self.__format(
 			outputType = outputType,
 			directory = directory,
@@ -430,7 +433,8 @@ class Profile:
 	def show(self, style="light", color=colors["green"], parallel=False):
 		""" display computed profile
 
-		Args:
+		Parameters:
+		-----------
 			style: style of generated output ("light")
 			color: mainly used color of given style (RGB values in [0,1])
 			parallel: run some additional parts of the generation in parallel (experimental)
@@ -637,10 +641,10 @@ class Profile:
 									value = self.__correlations[category][keyA][keyB]
 								except:
 									value = self.__correlations[category][keyB][keyA]
-								if outputType == "HTML":
-									result += "<div class=\"Thumbnail_ScatterPlot\" data-title=\"" + keyB + "\" data-title-second=\"" + keyA + "\"><img src=\"data:image/svg+xml;utf8," + value["image"] + "\" /></div>"
-								elif outputType == "LaTeX":
-									result += "\n\\includegraphics[width=0.5\\textwidth]{{\"" + value["image"] + "\"}.pdf}"
+#								if outputType == "HTML":
+#									result += "<div class=\"Thumbnail_ScatterPlot\" data-title=\"" + keyB + "\" data-title-second=\"" + keyA + "\"><img src=\"data:image/svg+xml;utf8," + value["image"] + "\" /></div>"
+#								elif outputType == "LaTeX":
+#									result += "\n\\includegraphics[width=0.5\\textwidth]{{\"" + value["image"] + "\"}.pdf}"
 				return result
 			results[category]["Correlations"]["ScatterPlots"] += funcScatterPlot(category)
 
@@ -735,7 +739,6 @@ class Profile:
 
 	def __loadProperties(self):
 		""" calculate the network properties """
-		self.__properties["Name"] = self.__G.getName()
 		self.__properties["Nodes"] = self.__G.numberOfNodes()
 		self.__properties["Edges"] = self.__G.numberOfEdges()
 		self.__properties["Density"] = kit.graphtools.density(self.__G)
@@ -947,7 +950,8 @@ class Profile:
 def walk(inputDir, outputDir, graphFormat, filePattern="*",  preset="default", config=None, outputType="HTML", style="light", color=colors["green"], recursive=False, parallel=False):
 	""" tests all files of a directory for the given conditions and generates a profile when matching
 
-	Args:
+	Parameters:
+	-----------
 		inputDir: the directory to search
 		filePattern: specify accepted file names, e.g.: *.METIS.graph
 		outputDir: directory to write the generated profiles
