@@ -1,6 +1,8 @@
 #!/usr/bin/env python3
-import unittest
+import numpy as np
 import os
+import random
+import unittest
 
 import networkit as nk
 
@@ -86,6 +88,25 @@ class TestSelfLoops(unittest.TestCase):
 		testTopKRanking(False)
 		testTopKRanking(True)
 
+	def testCentralityTopHarmonicCloseness(self):
+		CC = nk.centrality.HarmonicCloseness(self.L, False)
+		CC.run()
+		scores = CC.scores()
+		tol = 1e-6
+		k = 5
+
+		for useNBbound in [True, False]:
+			thc = nk.centrality.TopHarmonicCloseness(self.L, k, useNBbound).run()
+			self.assertEqual(len(thc.topkNodesList()), k)
+			self.assertEqual(len(thc.topkScoresList()), k)
+			self.assertGreaterEqual(len(thc.topkNodesList(True)), k)
+			self.assertGreaterEqual(len(thc.topkScoresList(True)), k)
+
+			for node, score in zip(thc.topkNodesList(True), thc.topkScoresList(True)):
+				self.assertAlmostEqual(score, scores[node], delta=tol)
+
+			for score_thc, score in zip(thc.topkScoresList(True), sorted(scores, reverse=True)):
+				self.assertAlmostEqual(score_thc, score, delta=tol)
 
 	def testCentralityCoreDecomposition(self):
 		CL = nk.centrality.CoreDecomposition(self.L)
@@ -377,7 +398,6 @@ class TestSelfLoops(unittest.TestCase):
 		PLMLL.run()
 		PLMLLP = PLMLL.getPartition()
 		CG = nk.community.communityGraph(self.LL, PLMLLP)
-		self.assertIsInstance(len(CG.nodes()), int)
 
 
 	def testCommunityEvaluateCommunityDetection(self):
@@ -396,7 +416,7 @@ class TestSelfLoops(unittest.TestCase):
 		r1 = nk.graphtools.randomNode(self.L)
 		r2 = nk.graphtools.randomNode(self.L)
 		while r1 is r2:
-			r2 = self.L.randomNode()
+			r2 = nk.graphtools.randomNode(self.L)
 		EKL = nk.flow.EdmondsKarp(self.L, r1, r2)
 		EKLL = nk.flow.EdmondsKarp(self.LL, r1, r2)
 		EKL.run()
@@ -591,6 +611,43 @@ class TestSelfLoops(unittest.TestCase):
 		testMesh(9, 18)
 		testMesh(7, 1)
 
+	def testApproxElectricalClosenes(self):
+		for seed in [1, 2, 3]:
+			nk.engineering.setSeed(seed, True)
+			g = nk.generators.ErdosRenyiGenerator(50, 0.15, False).generate()
+			g = nk.components.ConnectedComponents(g).extractLargestConnectedComponent(g, True)
+			eps = 0.1
+			apx = nk.centrality.ApproxElectricalCloseness(g, eps).run().getDiagonal()
+
+			# Create laplacian matrix
+			L = np.zeros((g.numberOfNodes(), g.numberOfNodes()))
+			for u in g.iterNodes():
+				L[u, u] = g.degree(u)
+				for v in g.iterNeighbors(u):
+					L[u, v] = -1
+					L[v, u] = -1
+
+			pinv = np.linalg.pinv(L).diagonal()
+			for u in g.iterNodes():
+				self.assertLessEqual(abs(apx[u] - pinv[u]), eps)
+
+	def testDistanceSPSP(self):
+		nk.engineering.setSeed(1, True)
+		random.seed(1)
+		for directed in [True, False]:
+			for weighted in [True, False]:
+				g = nk.generators.ErdosRenyiGenerator(100, 0.15, directed).generate()
+				if weighted:
+					g = nk.graphtools.toWeighted(g)
+					g.forEdges(lambda u, v, ew, eid: g.setWeight(u, v, random.random()))
+				for nSources in [1, 10, 50]:
+					sources = set()
+					while len(sources) < nSources:
+						sources.add(nk.graphtools.randomNode(g))
+
+					spsp = nk.distance.SPSP(g, list(sources))
+					spsp.run()
+					spsp.getDistances()
 
 if __name__ == "__main__":
 	unittest.main()
